@@ -539,10 +539,10 @@ def compute_best_k(k,score,score_sd,mode='greatest',out='single'):
 		# compute local sd
 		if (k_idx == 0):
 			local_sd = np.max([score_sd[k_idx],score_sd[k_idx+1]])
-			comp_score = score[k_idx+1]
+			comp_score = 0 #score[k_idx+1]
 		elif (k_idx == len(k)-1):
 			local_sd = np.max([score_sd[k_idx-1],score_sd[k_idx]])
-			comp_score = score[k_idx-1]
+			comp_score = 0 #score[k_idx-1]
 		elif (k_idx > 0) and (k_idx < len(k)-1):
 			local_sd = np.max([score_sd[k_idx-1],score_sd[k_idx],score_sd[k_idx+1]])
 			comp_score = np.min([score[k_idx-1],score[k_idx+1]])
